############
Contributors
############

Here is an alphabetically-ordered list of
the people who contributed to this software:

* Alexander Wagner <https://ip7.tech/>
* Andreas Büchler <https://www.coperion.com/>
* Andreas Motl <andreas.motl@elmyra.de>
* Andreas Sykora <http://www.q-ip.de/sykora-lang.php>
* Andrii Danyleiko <https://github.com/DefteZ>
* Arne Krüger <https://depa.tech/>
* Benjamin Walter <b.walter@europatent.net>
* David Santamauro <https://www.ificlaims.com/>
* Erik Zscherpe <http://blumpatentrecherchen.de/>
* Ernst Fischer <http://www.pateris.de/dr-ernst-fischer/>
* Felix Berkemeier <http://www.patente.de/en/dr-felix-berkemeier.html>
* Frank Heider <https://github.com/frankheider>
* Gaby Strauß <http://www.patentberichterstatter-muenchen.de/>
* Johannes Steimel <https://www.festool.com/>
* Klaus Hager <http://www.patentberichterstatter-muenchen.de/>
* Lars Witte <https://www.patentfamily.com/>
* Luca Martinuzzi <http://www.patentberichterstatter-muenchen.de/>
* Marc Haus <https://depa.tech/>
* Martin Bock <http://www.serviva.com/>
* Martin Glatzer <https://www.guentner.com/>
* Michael Behl <m.behl@europatent.net>
* Papoteur <https://github.com/papoteur-mga>
* Raphael Jung <http://www.serviva.com/>
* Robert Frenzel <http://www.serviva.com/>
* Siegfried Greiner <http://greiner-mv.de/>
* Steffen Köhler <s.koehler@europatent.net>
* Uwe Spadaccini <http://www.serviva.com/>
* Wilhelm von Krüchten <http://www.patentberichterstatter-muenchen.de/>
* Wolf-Rüdiger von Gartzen <gartzen@europatent.net>

Thanks a bunch!
